<?php
/**
 * Copyright 2003-2005 Marko Djukic <marko@oblo.com>
 * Copyright 2003-2005 Chuck Hagenbuch <chuck@horde.org>
 *
 * $Horde: jonah/stories/index.php,v 1.40 2005/01/03 14:35:09 jan Exp $
 *
 * See the enclosed file LICENSE for license information (BSD). If you
 * did not receive this file, see http://cvs.horde.org/co.php/jonah/LICENSE.
 */

@define('JONAH_BASE', dirname(__FILE__) . '/..');
require_once JONAH_BASE . '/lib/base.php';
require_once JONAH_BASE . '/lib/News.php';

$news = &Jonah_News::singleton();

/* Redirect to the news index if no channel_id is specified. */
$channel_id = Util::getFormData('channel_id');
if (empty($channel_id)) {
    $notification->push(_("No channel requested."), 'horde.error');
    $url = Horde::applicationUrl('channels/index.php', true);
    header('Location: ' . $url);
    exit;
}

$channel = $news->getChannel($channel_id);
if (!Jonah::checkPermissions(Jonah::typeToPermName($channel['channel_type']), PERMS_EDIT, $channel_id)) {
    $notification->push(_("You are not authorised for this action."), 'horde.warning');
    Horde::authenticationFailureRedirect();
}

/* Check if a forced refresh is being called for an external channel. */
$refresh = Util::getFormData('refresh');

/* Check if a URL has been passed. */
$url = Util::getFormData('url');

$stories = $news->getStories($channel_id, null, 0, !empty($refresh));
if (is_a($stories, 'PEAR_Error')) {
    $notification->push(sprintf(_("Invalid channel requested. %s"), $stories->getMessage()), 'horde.error');
    $url = Horde::applicationUrl('channels/index.php', true);
    header('Location: ' . $url);
    exit;
} else {
    /* Do some state tests. */
    if (empty($stories)) {
        $notification->push(_("No available stories."), 'horde.warning');
    }
    if (!empty($refresh)) {
        $notification->push(_("Channel refreshed."), 'horde.success');
    }
    if (!empty($url)) {
        header('Location: ' . $url);
        exit;
    }

    /* Get channel details, for title, etc. */
    $channel = $news->getChannel($channel_id);
    if (empty($channel['channel_story_url'])) {
        $story_url = Horde::applicationUrl('stories/view.php');
        $story_url = Util::addParameter($story_url, array('channel_id' => '%c', 'story_id' => '%s'));
        $story_url = str_replace(array('%25c', '%25s'), array('%c', '%s'), $story_url);
    } else {
        $story_url = $channel['channel_story_url'];
    }

    /* Build story specific fields. */
    foreach ($stories as $key => $story) {
        /* These links only if internal channel. */
        if ($channel['channel_type'] == JONAH_INTERNAL_CHANNEL) {
            $stories[$key]['view_link'] = Horde::link(str_replace(array('%c', '%s'), array($channel_id, $story['story_id']), $story_url), $story['story_title'], '', '_blank', '', $story['story_title']) . $story['story_title'] . '</a>';

            /* Edit story link. */
            $url = Horde::applicationUrl('stories/edit.php');
            $url = Util::addParameter($url, array('story_id' => $story['story_id'], 'channel_id' => $channel_id));
            $stories[$key]['edit_link'] = Horde::link($url, _("Edit story"), '', '', '', _("Edit story")) . Horde::img('edit.png', _("Edit story"), '', $registry->getImageDir('horde')) . '</a>';

            /* Delete story link. */
            $url = Horde::applicationUrl('stories/delete.php');
            $url = Util::addParameter($url, array('story_id' => $story['story_id'], 'channel_id' => $channel_id));
            $stories[$key]['delete_link'] = Horde::link($url, _("Delete story"), '', '', '', _("Delete story")) . Horde::img('delete.png', _("Delete story"), '', $registry->getImageDir('horde')) . '</a>';

            /* Comment counter. */
            if ($conf['comments']['allow'] &&
                $registry->hasMethod('forums/numMessages')) {
                $stories[$key]['comments'] = $registry->call('forums/numMessages', array($stories[$key]['story_id'], 'jonah'));
            }
        } else {
            $stories[$key]['view_link'] = Horde::link($story['story_url'], $story['story_title'], '', '_blank', '', $story['story_title']) . $story['story_title'] . '</a>';
        }
    }
}

/* Set up the template action links. */
$actions = array();
/* Show an new story link only if internal channel. */
if ($channel['channel_type'] == JONAH_INTERNAL_CHANNEL) {
    $url = Horde::applicationUrl('stories/edit.php');
    $actions[_("New Story")] = Util::addParameter($url, 'channel_id', $channel_id);
}
/* Show a link to list management. */
if (Auth::isAdmin()) {
    $url = Horde::applicationUrl('lists/index.php');
    $actions[_("Lists")] = Util::addParameter($url, 'channel_id', $channel_id);
}
$template->setOption('gettext', true);
$template->set('actions', Jonah::setupActions($actions));

$template->set('header', sprintf(_("Channel '%s'"), $channel['channel_name']));
$template->set('listheaders', array(_("Story"), _("Updated")));
$template->set('stories', $stories, true);
$template->set('read', $channel['channel_type'] == JONAH_INTERNAL_CHANNEL || $channel['channel_type'] == JONAH_COMPOSITE_CHANNEL, true);
$template->set('comments', $conf['comments']['allow'] && $registry->hasMethod('forums/numMessages'));
$template->set('menu', Jonah::getMenu('string'));
$template->set('notify', Util::bufferOutput(array($notification, 'notify'), array('listeners' => 'status')));

require JONAH_TEMPLATES . '/common-header.inc';
echo $template->fetch(JONAH_TEMPLATES . '/stories/index.html');
require $registry->get('templates', 'horde') . '/common-footer.inc';
